pub struct OutputMatch {
pub equivalence: Option<FHIRCode>,
pub concept: Option<Coding>,
pub product: Option<Vec<OutputMatchProduct>>,
pub source: Option<FHIRUri>,
}Fields
equivalence: Option<FHIRCode>A code indicating the equivalence of the translation, using values from ConceptMapEquivalence
concept: Option<Coding>The translation outcome. Note that this would never have userSelected = true, since the process of translations implies that the user is not selecting the code (and only the client could know differently)
product: Option<Vec<OutputMatchProduct>>Another element that is the product of this mapping
source: Option<FHIRUri>The canonical reference to the concept map from which this mapping comes from