pub struct Input {Show 13 fields
pub url: Option<FHIRUri>,
pub conceptMap: Option<ConceptMap>,
pub conceptMapVersion: Option<FHIRString>,
pub code: Option<FHIRCode>,
pub system: Option<FHIRUri>,
pub version: Option<FHIRString>,
pub source: Option<FHIRUri>,
pub coding: Option<Coding>,
pub codeableConcept: Option<CodeableConcept>,
pub target: Option<FHIRUri>,
pub targetsystem: Option<FHIRUri>,
pub dependency: Option<Vec<InputDependency>>,
pub reverse: Option<FHIRBoolean>,
}Fields
url: Option<FHIRUri>A canonical URL for a concept map. The server must know the concept map (e.g. it is defined explicitly in the server’s concept maps, or it is defined implicitly by some code system known to the server.
conceptMap: Option<ConceptMap>The concept map is provided directly as part of the request. Servers may choose not to accept concept maps in this fashion.
conceptMapVersion: Option<FHIRString>The identifier that is used to identify a specific version of the concept map to be used for the translation. This is an arbitrary value managed by the concept map author and is not expected to be globally unique. For example, it might be a timestamp (e.g. yyyymmdd) if a managed version is not available.
code: Option<FHIRCode>The code that is to be translated. If a code is provided, a system must be provided
system: Option<FHIRUri>The system for the code that is to be translated
version: Option<FHIRString>The version of the system, if one was provided in the source data
source: Option<FHIRUri>Identifies the value set used when the concept (system/code pair) was chosen. May be a logical id, or an absolute or relative location. The source value set is an optional parameter because in some cases, the client cannot know what the source value set is. However, without a source value set, the server may be unable to safely identify an applicable concept map, and would return an error. For this reason, a source value set SHOULD always be provided. Note that servers may be able to identify an appropriate concept map without a source value set if there is a full mapping for the entire code system in the concept map, or by manual intervention
coding: Option<Coding>A coding to translate
codeableConcept: Option<CodeableConcept>A full codeableConcept to validate. The server can translate any of the coding values (e.g. existing translations) as it chooses
target: Option<FHIRUri>Identifies the value set in which a translation is sought. May be a logical id, or an absolute or relative location. If there’s no target specified, the server should return all known translations, along with their source
targetsystem: Option<FHIRUri>identifies a target code system in which a mapping is sought. This parameter is an alternative to the target parameter - only one is required. Searching for any translation to a target code system irrespective of the context (e.g. target valueset) may lead to unsafe results, and it is at the discretion of the server to decide when to support this operation
dependency: Option<Vec<InputDependency>>Another element that may help produce the correct mapping
reverse: Option<FHIRBoolean>if this is true, then the operation should return all the codes that might be mapped to this code. This parameter reverses the meaning of the source and target parameters