pub struct Output {
pub result: FHIRBoolean,
pub message: Option<FHIRString>,
pub match_: Option<Vec<OutputMatch>>,
}Fields
result: FHIRBooleanTrue if the concept could be translated successfully. The value can only be true if at least one returned match has an equivalence which is not unmatched or disjoint
message: Option<FHIRString>Error details, for display to a human. If this is provided when result = true, the message carries hints and warnings (e.g. a note that the matches could be improved by providing additional detail)
match_: Option<Vec<OutputMatch>>A concept in the target value set with an equivalence. Note that there may be multiple matches of equal or differing equivalence, and the matches may include equivalence values that mean that there is no match